[![CircleCI](https://circleci.com/gh/mkeshav/data-genie.svg?style=shield)](https://circleci.com/gh/mkeshav/data-genie)
[![PyPI version](https://badge.fury.io/py/data-genie.svg)](https://badge.fury.io/py/data-genie)
[![Documentation Status](https://readthedocs.org/projects/data-genie/badge/?version=latest)](https://data-genie.readthedocs.io/en/latest/?badge=latest)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/2ed18483f4094f378945727c11eb7ab2)](https://www.codacy.com/gh/mkeshav/data-genie/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=mkeshav/data-genie&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/2ed18483f4094f378945727c11eb7ab2)](https://www.codacy.com/gh/mkeshav/data-genie/dashboard?utm_source=github.com&utm_medium=referral&utm_content=mkeshav/data-genie&utm_campaign=Badge_Coverage)

# Data Genie

Genie that can satisfy your data wish. **Python 3.5+**

## QuickStart

- `python3 -m pip install data-genie`
- Detailed [Documentation](https://data-genie.readthedocs.io)

## Supported Formats

- Fixed Width
- Delimited (CSV)
- JSON

## Data quality

`dqc` module allows to write data quality checks on pandas data frame.
